==> haskell-asn1-encoding-0.9.5-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-asn1-encoding.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-encoding
version: 0.9.5
id: asn1-encoding-0.9.5-AYmXiFOdrRwKi8Cg1ahrRP
key: asn1-encoding-0.9.5-AYmXiFOdrRwKi8Cg1ahrRP
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-asn1
synopsis: ASN1 data reader and writer in RAW, BER and DER forms
description:
    ASN1 data reader and writer in raw form with supports for high level forms of ASN1 (BER, and DER).
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.ASN1.Error Data.ASN1.BinaryEncoding
    Data.ASN1.BinaryEncoding.Raw Data.ASN1.Encoding Data.ASN1.Stream
    Data.ASN1.Object
hidden-modules: Data.ASN1.Prim Data.ASN1.BinaryEncoding.Parse
                Data.ASN1.BinaryEncoding.Writer Data.ASN1.Internal
                Data.ASN1.Serialize Data.ASN1.Get
abi: 47bb7929473155377c4d11391640f5de
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/asn1-encoding-0.9.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/asn1-encoding-0.9.5
data-dir: /usr/share/arm-linux-ghc-8.0.1/asn1-encoding-0.9.5
hs-libraries: HSasn1-encoding-0.9.5-AYmXiFOdrRwKi8Cg1ahrRP
depends:
    asn1-types-0.3.2-F5URSnYSqnC31ETtsSFK0a base-4.9.0.0
    bytestring-0.10.8.1 hourglass-0.2.10-I8h0J4RSF89FN6CuD9x2Xx
haddock-interfaces: /usr/share/doc/haskell-asn1-encoding/html/asn1-encoding.haddock
haddock-html: /usr/share/doc/haskell-asn1-encoding/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-asn1-encoding-0.9.5-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-asn1-encoding.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-encoding
version: 0.9.5
id: asn1-encoding-0.9.5-4hijzDN35y4QB3uXzlCct
key: asn1-encoding-0.9.5-4hijzDN35y4QB3uXzlCct
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-asn1
synopsis: ASN1 data reader and writer in RAW, BER and DER forms
description:
    ASN1 data reader and writer in raw form with supports for high level forms of ASN1 (BER, and DER).
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.ASN1.Error Data.ASN1.BinaryEncoding
    Data.ASN1.BinaryEncoding.Raw Data.ASN1.Encoding Data.ASN1.Stream
    Data.ASN1.Object
hidden-modules: Data.ASN1.Prim Data.ASN1.BinaryEncoding.Parse
                Data.ASN1.BinaryEncoding.Writer Data.ASN1.Internal
                Data.ASN1.Serialize Data.ASN1.Get
abi: 74626ed38b582395a8455a78347ad56c
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/asn1-encoding-0.9.5
library-dirs: /usr/lib/ghc-8.0.2/site-local/asn1-encoding-0.9.5
dynamic-library-dirs: /usr/lib/arm-linux-ghc-8.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.2/asn1-encoding-0.9.5
hs-libraries: HSasn1-encoding-0.9.5-4hijzDN35y4QB3uXzlCct
depends:
    asn1-types-0.3.2-5wnfVxEnJ3kDfiPJu0Wloe base-4.9.1.0
    bytestring-0.10.8.1 hourglass-0.2.10-pnbvWmzfcY1rOFETQEmcY
haddock-interfaces: /usr/share/doc/haskell-asn1-encoding/html/asn1-encoding.haddock
haddock-html: /usr/share/doc/haskell-asn1-encoding/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
